@@ -31,7 +31,11 @@
 G_BEGIN_DECLS
 
 #define STRICT
+#ifndef _WIN32_WINNT
+#define _WIN32_WINNT 0x0501	/* To get ClearType-related macros */
+#endif
 #include <windows.h>
+#undef STRICT
 
 #define PANGO_RENDER_TYPE_WIN32 "PangoRenderWin32"
 
@@ -50,32 +54,51 @@ void           pango_win32_render_layout_line (HDC               hdc,
 					       int               y);
 void           pango_win32_render_layout      (HDC               hdc,
 					       PangoLayout      *layout,
-					       int               x, 
+					       int               x,
 					       int               y);
 
+void           pango_win32_render_transformed (HDC         hdc,
+					       const PangoMatrix *matrix,
+					       PangoFont         *font,
+					       PangoGlyphString  *glyphs,
+					       int                x,
+					       int                y);
 
+#ifdef PANGO_ENABLE_ENGINE
 
-/* API for rendering modules
+/* For shape engines
  */
 
-PangoGlyph             pango_win32_get_unknown_glyph    (PangoFont        *font);
-PangoCoverage         *pango_win32_font_get_coverage    (PangoFont        *font,
-							 PangoLanguage    *lang);
-gint                   pango_win32_font_get_glyph_index (PangoFont        *font,
-							 gunichar          wc);
+#ifndef PANGO_DISABLE_DEPRECATED
+PangoGlyph     pango_win32_get_unknown_glyph  (PangoFont        *font,
+					       gunichar          wc);
+#endif /* PANGO_DISABLE_DEPRECATED */
+gint	      pango_win32_font_get_glyph_index(PangoFont        *font,
+					       gunichar          wc);
+
+HDC            pango_win32_get_dc             (void);
+
+gboolean       pango_win32_get_debug_flag     (void);
+
+gboolean pango_win32_font_select_font        (PangoFont *font,
+					      HDC        hdc);
+void     pango_win32_font_done_font          (PangoFont *font);
+double   pango_win32_font_get_metrics_factor (PangoFont *font);
+
+#endif
 
 /* API for libraries that want to use PangoWin32 mixed with classic
  * Win32 fonts.
  */
 typedef struct _PangoWin32FontCache PangoWin32FontCache;
-  
+
 PangoWin32FontCache *pango_win32_font_cache_new          (void);
 void                 pango_win32_font_cache_free         (PangoWin32FontCache *cache);
- 
+
 HFONT                pango_win32_font_cache_load         (PangoWin32FontCache *cache,
-						          const LOGFONT       *logfont);
+							  const LOGFONT       *logfont);
 void                 pango_win32_font_cache_unload       (PangoWin32FontCache *cache,
-						     	  HFONT                hfont);
+							  HFONT                hfont);
 
 PangoFontMap        *pango_win32_font_map_for_display    (void);
 void                 pango_win32_shutdown_display        (void);
@@ -83,6 +106,8 @@ PangoWin32FontCache *pango_win32_font_map_get_font_cache (PangoFontMap       *fo
 
 LOGFONT             *pango_win32_font_logfont            (PangoFont          *font);
 
+PangoFontDescription *pango_win32_font_description_from_logfont (const LOGFONT *lfp);
+
 G_END_DECLS
 
 #endif /* __PANGOWIN32_H__ */
